from django.db import models
from uuid import uuid4


# Create your models here.
class Article(models.Model):
    """
    文章类型
    """
    ARTICLE_STATUS = (
        ('0', '正常'),
        ('1', '删除')
    )
    id = models.UUIDField(verbose_name = '文章编号', auto_created = True,
                          default = uuid4, primary_key = True)

    title = models.CharField(verbose_name = '文章标题', max_length = 100)

    content = models.TextField(verbose_name = '文章内容')

    pub_time = models.DateTimeField(verbose_name = '发布时间', auto_now = True)

    read_count = models.IntegerField(verbose_name = '阅读次数', default = 0)

    admired_count = models.IntegerField(verbose_name = '点赞次数', default = 0)

    liked_count = models.IntegerField(verbose_name = '喜欢次数', default = 0)

    collected_count = models.IntegerField(verbose_name = '收藏次数', default = 0)

    commented_count = models.IntegerField(verbose_name = '评论次数', default = 0)

    up_time = models.DateTimeField(verbose_name = '上次修改时间', auto_now = True)

    status = models.CharField(verbose_name = '当前状态', choices = ARTICLE_STATUS,
                              default = 0, max_length = 3)

    author = models.ForeignKey("author.Author", on_delete = models.CASCADE)

    class Meta:
        ordering = ['-pub_time', 'id']

    def __str__(self):
        return f'文章标题: {self.title}, 文章内容: {self.content}'
