from django.db import models
from uuid import uuid4
from datetime import datetime


# Create your models here.
class Author(models.Model):
    """
    用户类型: 博客作者
    """
    GENDER = (
        ('0', '女'),
        ('1', '男'),
    )
    STATUS = (
        ('0', '正常'),
        ('1', '锁定'),
        ('2', '删除'),
    )
    id = models.UUIDField(primary_key = True, verbose_name = '作者编号',
                          auto_created = True, default = uuid4)

    username = models.CharField(max_length = 50, verbose_name = '登录账号',
                                unique = True, db_index = True)

    password = models.CharField(max_length = 50, verbose_name = '登录密码')

    realname = models.CharField(max_length = 20, verbose_name = '作者姓名', default = '待完善',
                                null = True, blank = True, db_index = True)

    nickname = models.CharField(max_length = 20, verbose_name = '作者昵称',
                                unique = True, null = True, blank = True, db_index = True)

    age = models.IntegerField(default = 0, verbose_name = '作者年龄')

    gender = models.CharField(max_length = 1, choices = GENDER, verbose_name = '性别',
                              null = True, blank = True)

    email = models.EmailField(verbose_name = '联系邮箱', null = True,
                              blank = True, db_index = True)

    phone = models.CharField(max_length = 20, verbose_name = '联系电话',
                             db_index = True, null = True, blank = True)

    status = models.CharField(max_length = 5, choices = STATUS,
                              verbose_name = '用户状态', help_text = '必须选择其中一个状态')

    create_time = models.DateTimeField(auto_now = True, verbose_name = '注册时间')

    update_time = models.DateTimeField(auto_now = True, verbose_name = '修改时间')

    personal_page = models.URLField(verbose_name = '个人主页', null = True, blank = True)

    intro = models.TextField(verbose_name = '个人介绍', null = True, blank = True)

    remark = models.TextField(verbose_name = '备注信息', null = True, blank = True)

    class Meta:
        """
        后台管理系统中的名称
        """
        verbose_name_plural = '作者'

    def __str__(self):
        return f'账号: {self.username}; 昵称: {self.nickname}; 姓名: {self.realname}'
